/*
 *               ParaStation
 *
 * Copyright (C) 2008 ParTec Cluster Competence Center GmbH, Munich
 *
 * $Id: psidutil.h 5383 2007-11-28 18:30:21Z eicker $
 *
 */
/**
 * \file
 * Utilities for SMT detection on Intel IA32
 *
 * $Id: psidutil.h 5383 2007-11-28 18:30:21Z eicker $
 *
 * \author
 * Norbert Eicker <eicker@par-tec.com>
 *
 */
#ifndef __PSIDINTEL_H
#define __PSIDINTEL_H

#ifdef __cplusplus
extern "C" {
#if 0
} /* <- just for emacs indentation */
#endif
#endif

/**
 * @brief Test for Intel CPU
 *
 * Test for Genuine Intel Processor. Use the CPUID instruction to get
 * magic string identifying the CPU to be made by Intel.
 *
 * @return Returns 1 if the processor is Genuine Intel, or otherwise
 * 0.
 */
int PSID_GenuineIntel(void);

/**
 * @brief Get number of physical CPUs on Intel IA-32.
 *
 * Determine the number of physical CPUs. The number of physical CPUs
 * might differ from the number of virtual CPUs e.g. on newer Pentium
 * platforms which support the Hyper-Threading Technology.
 *
 * This function only supports the Intel IA32 platform. For other
 * platforms, similar functionality has to be implemented. Be aware of
 * the fact that detecting the underlying hardware structure is
 * massively hardware dependant.
 *
 * The implementation assumes that all physical processors (i.e. the
 * device sitting within the socket of a motherboard) are identical.
 *
 * @return On success, the number of physical CPUs is returned. If an
 * error occurred, e.g. the current platform is no Genuine Intel, the
 * number of virtual CPUs is returned.
 */
long PSID_getPhysCPUs_IA32(void);

#ifdef __cplusplus
}/* extern "C" */
#endif

#endif /* __PSIDINTEL_H */
