/*
 *               ParaStation
 *
 * Copyright (C) 2007 ParTec Cluster Competence Center GmbH, Munich
 *
 * $Id: psilogger.h 5479 2007-12-21 14:07:05Z eicker $
 *
 *
 */
/**
 * \file
 * psilogger.h: Log-daemon for ParaStation I/O forwarding facility 
 *
 * $Id: psilogger.h 5479 2007-12-21 14:07:05Z eicker $ 
 *
 * \author
 * Michael Rauh <rauh@par-tec.com>
 */

#ifndef __PSILOGGER
#define __PSILOGGER


#include "pslog.h"
#include "pstask.h"

/**
 * @brief Send a PSLog message.
 *
 * Send a PSLog message of length @a count referenced by @a buf with
 * type @a type to @a destTID.
 *
 * This is mainly a wrapper for PSLog_write().
 *
 *
 * @param tid ParaStation task ID of the task the message is sent to.
 *
 * @param type Type of the message.
 *
 * @param buf Pointer to the buffer containing the data to send within
 * the body of the message. If @a buf is NULL, the body of the PSLog
 * message will be empty.
 *
 * @param len Amount of meaningfull data within @a buf in bytes. If @a
 * len is larger the 1024, more than one message will be generated.
 * The number of messages can be computed by (len/1024 + 1).
 *
 *
 * @return On success, the number of bytes written is returned,
 * i.e. usually this is @a len. On error, -1 is returned, and errno is
 * set appropriately.
 */
int sendMsg(PStask_ID_t tid, PSLog_msg_t type, char *buf, size_t len);

/**
 * @brief Terminate the Job.
 *
 * Send first TERM and then KILL signal to all the job's processes.
 *
 * @return No return value.
 */
void terminateJob(void);

#endif
